@@ -2,13 +2,11 @@
 # -*- coding: utf-8 -*-
 
 import hashlib
-import math
-from collections import defaultdict
 
 import sqlalchemy as sa
 
 from holmes.models import Base
-
+from holmes.models.domain import Domain
 
 class Limiter(Base):
     __tablename__ = "limiters"
@@ -31,11 +29,17 @@ class Limiter(Base):
         return str(self)
 
     @classmethod
-    def get_all(cls, db):
-        return db \
-            .query(Limiter) \
-            .order_by(sa.func.char_length(Limiter.url)) \
-            .all()
+    def get_all(cls, db, domain_filter=None):
+        query = db.query(Limiter)
+
+        if domain_filter:
+            domain = Domain.get_domain_by_name(domain_filter, db)
+            if domain:
+                query = query.filter(Limiter.url.startswith(domain.url))
+
+        return query \
+               .order_by(sa.func.char_length(Limiter.url)) \
+               .all()
 
     @classmethod
     def by_url(cls, url, db):
@@ -94,55 +98,3 @@ class Limiter(Base):
                     limiters.append(limiter)
 
         return limiters
-
-    @classmethod
-    def get_limiters_per_domains(cls, db, active_domains):
-        from holmes.models import Limiter  # Avoid circular dependency
-
-        all_limiters = Limiter.get_all(db)
-
-        limiters = defaultdict(list)
-        for limiter in all_limiters:
-            for domain in active_domains:
-                if limiter.matches(domain.url):
-                    limiters[domain.id].append(limiter)
-
-        return limiters
-
-    @classmethod
-    def _get_limiter_for_url(cls, limiters, url):
-        for limiter in limiters:
-            if limiter.matches(url):
-                return limiter
-
-        return None
-
-    @classmethod
-    def has_limit_to_work(cls, db, cache, active_domains, url, avg_links_per_page=10):
-        if avg_links_per_page < 1:
-            avg_links_per_page = 1
-
-        limiters = Limiter.get_limiters_for_domains(db, active_domains)
-
-        limiter = Limiter._get_limiter_for_url(limiters, url)
-
-        if limiter:
-            worker_count = cache.get_limit_usage(limiter.url)
-
-            if worker_count >= math.ceil(float(limiter.value) / float(avg_links_per_page)):
-                return False
-
-        return True
-
-
-    @classmethod
-    def get_limit_capacity(cls, db, active_domains):
-        limiters = Limiter.get_limiters_per_domains(db, active_domains)
-
-        usage = defaultdict(int)
-
-        for domain_id, domain_limiters in limiters.items():
-            for limiter in domain_limiters:
-                usage[domain_id] += limiter.value
-
-        return usage
