@@ -31,7 +31,7 @@ class Review(Base):
     facts = relationship("Fact", cascade="all,delete")
     violations = relationship("Violation", cascade="all,delete")
 
-    def to_dict(self, fact_definitions, violation_definitions):
+    def to_dict(self, fact_definitions, violation_definitions, _):
         return {
             'page': self.page and self.page.to_dict() or None,
             'domain': self.domain and self.domain.name or None,
@@ -39,8 +39,9 @@ class Review(Base):
             'uuid': str(self.uuid),
             'createdAt': self.created_date,
             'completedAt': self.completed_date,
-            'facts': [fact.to_dict(fact_definitions) for fact in self.facts],
-            'violations': [violation.to_dict(violation_definitions) for violation in self.violations]
+            'facts': [fact.to_dict(fact_definitions, _) for fact in self.facts],
+            'violations': [violation.to_dict(violation_definitions, _)
+                           for violation in self.violations]
         }
 
     def __str__(self):
@@ -168,16 +169,23 @@ class Review(Base):
     @classmethod
     def get_by_violation_key_name(cls, db, key_id, current_page=1, page_size=10, domain_filter=None, page_filter=None):
         from holmes.models.page import Page  # to avoid circular dependency
+        from holmes.models.domain import Domain  # to avoid circular dependency
 
         lower_bound = (current_page - 1) * page_size
         upper_bound = lower_bound + page_size
 
-        query = db.query(
-            Page.last_review_uuid.label('review_uuid'),
-            Page.url,
-            Page.uuid.label('page_uuid'),
-            Page.last_review_date.label('completed_date')
-        )
+        query = db \
+            .query(
+                Page.last_review_uuid.label('review_uuid'),
+                Page.url,
+                Page.uuid.label('page_uuid'),
+                Page.last_review_date.label('completed_date'),
+                Domain.name.label('domain_name')
+            ) \
+            .filter(
+                Domain.id == Page.domain_id
+            )
+
 
         query = cls._filter_by_violation_key_name(db, query, key_id, domain_filter, page_filter)
 
@@ -188,6 +196,10 @@ class Review(Base):
         from holmes.models import Page
 
         page = Page.by_uuid(page_uuid, db)
+
+        if page is None:
+            return
+
         last_review = page.last_review
 
         review = Review(
