@@ -34,10 +34,17 @@ class Violation(Base):
 
         value = definition.get('value_parser', lambda val: val)(self.value)
         description = _(definition.get('description', '%s'))
+
+        if value:
+            try:
+                description = (description % value)
+            except TypeError:
+                pass
+
         return {
             'key': self.key.name,
             'title': _(definition.get('title', _('undefined'))),
-            'description': (description % value) if value else description,
+            'description': description,
             'points': self.points,
             'category': _(definition.get('category', _('undefined')))
         }
@@ -65,20 +72,20 @@ class Violation(Base):
             .order_by('count desc').all()
 
     @classmethod
-    def get_by_key_id_group_by_domain(cls, db, key_id):
+    def get_group_by_key_id_for_all_domains(cls, db):
 
         from holmes.models.violation import Violation  # to avoid circular dependency
         from holmes.models.domain import Domain  # to avoid circular dependency
 
         return db \
             .query(
+                Violation.key_id,
                 Domain.name.label('domain_name'),
                 sa.func.count(Violation.id).label('violation_count')
             ) \
             .filter(Domain.id == Violation.domain_id) \
-            .filter(Violation.key_id == key_id) \
             .filter(Violation.review_is_active == True) \
-            .group_by(Domain.id) \
+            .group_by(Violation.key_id, Domain.id) \
             .order_by('violation_count DESC') \
             .all()
 
@@ -130,20 +137,22 @@ class Violation(Base):
             .all()
 
     @classmethod
-    def get_top_in_category_for_domain(cls, db, domain, key_category_id, limit=10):
+    def get_top_in_category_for_all_domains(cls, db, limit=1000):
         from holmes.models.keys import Key  # to avoid circular dependency
+        from holmes.models.domain import Domain  # to avoid circular dependency
         from holmes.models.violation import Violation  # to avoid circular dependency
 
         return db \
             .query(
+                Domain.name,
+                Key.category_id,
                 Key.name,
                 sa.func.count(Key.category_id).label('violation_count')
             ) \
-            .filter(Key.id == Violation.key_id) \
-            .filter(Violation.domain_id == domain.id) \
+            .filter(Domain.id == Violation.domain_id) \
+            .filter(Violation.key_id == Key.id) \
             .filter(Violation.review_is_active == True) \
-            .filter(Key.category_id == key_category_id) \
-            .group_by(Key.id) \
+            .group_by(Domain.id, Key.category_id, Key.id) \
             .order_by('violation_count DESC') \
             .limit(limit) \
             .all()
