@@ -14,7 +14,7 @@ from retools.lock import Lock, LockTimeout
 from holmes import __version__
 from holmes.reviewer import Reviewer, InvalidReviewError
 from holmes.utils import load_classes, count_url_levels, get_domain_from_url
-from holmes.models import Page, Request
+from holmes.models import Page, Request, Key, DomainsViolationsPrefs
 from holmes.cli import BaseCLI
 
 
@@ -93,14 +93,6 @@ class BaseWorker(BaseCLI):
     def publish(self, data):
         self.redis_pub_sub.publish('events', data)
 
-    def _insert_keys(self, keys):
-        from holmes.models import Key
-
-        for name in keys.keys():
-            key = Key.get_or_create(self.db, name)
-            keys[name]['key'] = key
-            self.db.add(key)
-
 
 class HolmesWorker(BaseWorker):
     def initialize(self):
@@ -110,13 +102,23 @@ class HolmesWorker(BaseWorker):
         self.last_ping = None
         self.last_update_pages_score = None
 
+        authnz_wrapper_class = self.load_authnz_wrapper()
+        if authnz_wrapper_class:
+            self.authnz_wrapper = authnz_wrapper_class(self.config)
+        else:
+            self.authnz_wrapper = None
+
         self.facters = self._load_facters()
         self.validators = self._load_validators()
         self.error_handlers = [handler(self.config) for handler in self.load_error_handlers()]
 
         self.connect_sqlalchemy()
 
-        self.search_provider = self.load_search_provider()(self.config, self.db)
+        self.search_provider = self.load_search_provider()(
+            config=self.config,
+            db=self.db,
+            authnz_wrapper=self.authnz_wrapper
+        )
 
         self.connect_to_redis()
         self.start_otto()
@@ -124,18 +126,41 @@ class HolmesWorker(BaseWorker):
         self.fact_definitions = {}
         self.violation_definitions = {}
 
+        self.default_violations_values = {}
+
         for facter in self.facters:
             self.fact_definitions.update(facter.get_fact_definitions())
 
-        self._insert_keys(self.fact_definitions)
+        Key.insert_keys(self.db, self.fact_definitions)
 
         for validator in self.validators:
             self.violation_definitions.update(validator.get_violation_definitions())
 
-        self._insert_keys(self.violation_definitions)
+            self.default_violations_values.update(
+                validator.get_default_violations_values(self.config)
+            )
+
+        Key.insert_keys(
+            self.db, self.violation_definitions, self.default_violations_values
+        )
 
         self.configure_material_girl()
 
+        DomainsViolationsPrefs.insert_default_violations_values_for_all_domains(
+            self.db,
+            self.default_violations_values,
+            self.violation_definitions,
+            self.cache
+        )
+
+        self.load_all_domains_violations_prefs()
+
+    def load_all_domains_violations_prefs(self):
+        from holmes.models import Domain
+
+        for domain in Domain.get_all_domains(self.db):
+            self.cache.get_domain_violations_prefs(domain.name)
+
     def config_parser(self, parser):
         parser.add_argument(
             '--concurrency',
@@ -267,7 +292,7 @@ class HolmesWorker(BaseWorker):
             self.working_url = job['url']
 
             if self.working_url:
-                self.domain_name, _ = get_domain_from_url(self.working_url)
+                self.domain_name, domain_url = get_domain_from_url(self.working_url)
 
             self._ping_api()
             job['lock'] = lock
